﻿#Prevent horrible red errors for customers
$ErrorActionPreference = "SilentlyContinue"
#Test network access: Ping 1.1.1.1
Write-Verbose "Testing internet access"
$pingresult = Test-NetConnection 1.1.1.1 -InformationLevel Detailed

$connections = @(
    New-Object PSObject -Property @{URL = "fe2.update.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "fe3.delivery.mp.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "login.microsoftonline.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "account.live.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "accountalt.azureedge.net";  Port = "443"}
    New-Object PSObject -Property @{URL = "secure.aadcdn.microsoftonline-p.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "portal.manage.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "r.manage.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "geo-prod.do.dsp.mp.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "kv601-prod.do.dsp.mp.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "cp601-prod.do.dsp.mp.microsoft.com";  Port = "443"}
    New-Object PSObject -Property @{URL = "swdc01.manage.microsoft.com";  Port = "443"}
)
Write-Verbose "Testing connection to AutoPilot services"
$connresults = foreach($conn in $connections){
    Test-NetConnection -ComputerName $conn.URL -Port $conn.Port -InformationLevel Detailed
}

Write-Verbose "Getting AutoPilot Configuration Data"
#Get Windows Version
$WinVersion = (Get-ItemProperty -Path "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion" -Name ReleaseId).ReleaseId

if ($WinVersion -ge '1709'){
$registry = Get-ItemProperty 'HKLM:\SOFTWARE\Microsoft\Provisioning\Diagnostics\AutoPilot'
}

Write-Verbose "Getting AutoPilot Event Log Data"
if ($WinVersion -gt '1709'){
#Show AutoPilot events
$events = Get-WinEvent -LogName 'Microsoft-Windows-Provisioning-Diagnostics-Provider/AutoPilot'
}

Write-Verbose "Saving Files"
New-Item -Path 'D:\AutoPilotTroubleShooting' -ItemType Directory | Out-Null
$pingresult | Export-Csv -Path D:\AutoPilotTroubleShooting\PingTest.csv -Encoding Default -Delimiter ";"
$connresults | Export-Csv -Path D:\AutoPilotTroubleShooting\Connections.csv -Encoding Default -Delimiter ";"
$WinVersion | Out-File -FilePath D:\AutoPilotTroubleShooting\WinVersion.txt
$registry | Export-Csv -Path D:\AutoPilotTroubleShooting\registry.csv -Encoding Default -Delimiter ";"
$events | Export-Csv -Path D:\AutoPilotTroubleShooting\events.csv -Encoding Default -Delimiter ";"

Write-Verbose "Creating ZIP"
Compress-Archive -Path D:\AutoPilotTroubleShooting -DestinationPath "D:\AutoPilot_$((Get-CimInstance -Class Win32_BIOS).SerialNumber)"
Write-Verbose "Cleaning up"
Remove-Item -Path 'D:\AutoPilotTroubleShooting' -Recurse -Force
Write-Verbose "Complete"